@@ -220,7 +220,7 @@ class Status:
         :return: 返回识别结果
         """
         assert self.model_path, '未加载识别模型！'
-        ocr_list = ['angle']
+        ocr_list = ['angle', 'wind']
         if model not in ocr_list:
             return None
         elif model == 'angle':
@@ -244,6 +244,33 @@ class Status:
             # 将模型的输出进行后处理，得到识别结果
             res = postprocess_func(output)[0][0]
             return int(res)
+        elif model == 'wind':
+            onnx_model_fp = self.model_path + '/wind/wind.onnx'
+            character_dict_fp = self.model_path + '/wind/wind_dict.txt'
+
+            image = self.capture()
+            b, g, r = image.item(21, 468, 0), image.item(21, 468, 1), image.item(21, 468, 2)
+            if b == 252 and g == r and g > 240 and r > 240:
+                face = 1
+            else:
+                face = -1
+
+            image = image[17:48, 461:537]
+            input_image_shape = (3, 48 - 17, 537 - 461)  # 模型的输入维度：通道数，高度，宽度
+
+            preprocess_func = ddtank.build_preprocess()  # 获取预处理函数
+            postprocess_func = ddtank.build_postprocess(character_dict_fp)  # 获取后处理函数
+            session = ddtank.load_onnx(onnx_model_fp)  # 加载模型
+
+            norm_image = preprocess_func(image, input_image_shape)  # 进行数据预处理
+
+            # 使用模型对预处理数据进行运算
+            input_name = session.get_inputs()[0].name
+            output = session.run([], {input_name: norm_image})
+
+            # 将模型的输出进行后处理，得到识别结果
+            res = postprocess_func(output)[0][0]
+            return float(res) * face
 
     # 条件识别
     def click_pixel(self, coordinate_x: int, coordinate_y: int, pixel: tuple, repeat: bool = True) -> bool:
@@ -308,12 +335,12 @@ class Status:
             return True
         return False
 
-    def find_image(self, template_image_name: str, position: tuple = (0, 0, 1000, 600)) -> tuple:
+    def find_image(self, template_image_name: str, position: tuple = (0, 0, 1000, 600)) -> Union[tuple, type(None)]:
         """
         寻找指定图像位置，需要先调用load_image方法指定图片资源文件夹路径
         :param template_image_name: 所要寻找的图片
         :param position: 寻找图片的范围: (x1, y1, x2, y2)，默认为全部
-        :return: 返回图片中心点坐标元组
+        :return: 返回图片中心点坐标元组，若找不到图片则返回None
         """
         assert self.image_path is not None
         template_image = ddtank.cv2.imread(self.image_path + '/' + template_image_name + '.png', 0)
@@ -322,9 +349,11 @@ class Status:
         image = ddtank.cv2.cvtColor(image, ddtank.cv2.COLOR_BGR2GRAY)
         res = ddtank.cv2.matchTemplate(image[y1:y2, x1:x2], template_image, ddtank.cv2.TM_CCOEFF_NORMED)
         min_val, max_val, min_loc, max_loc = ddtank.cv2.minMaxLoc(res)
-        w, h = template_image.shape[::-1]
-
-        return int(max_loc[0] + w / 2), int(max_loc[1] + h / 2)
+        if max_val >= 0.9:
+            w, h = template_image.shape[::-1]
+            return int(max_loc[0] + w / 2), int(max_loc[1] + h / 2)
+        else:
+            return None
 
     # 综合操作
     def press_shot(self, strength: int):
@@ -380,7 +409,7 @@ class Status:
 
         small_map_left_x = ddtank.np.argwhere(ddtank.np.all(status_img[1, 750:] == [160, 160, 160], axis=-1))[0, 0] + 742
 
-        img_res = ddtank.np.where(ddtank.np.any(status_img[24:120, small_map_left_x:998] != [153, 153, 153], axis=-1),0, 255).astype('uint8')
+        img_res = ddtank.np.where(ddtank.np.any(status_img[24:120, small_map_left_x:998] != [153, 153, 153], axis=-1), 0, 255).astype('uint8')
         contours, hierarchy = ddtank.cv2.findContours(img_res, ddtank.cv2.RETR_TREE, ddtank.cv2.CHAIN_APPROX_SIMPLE)
         for cnt in contours:
             x, y, w, h = ddtank.cv2.boundingRect(cnt)
@@ -399,7 +428,7 @@ class Status:
         return white_box, blue_point
 
     # 顶级操作
-    def shot(self, shot_angle: Union[int, tuple], shot_strength: int, shot_item: str):
+    def shot(self, shot_angle: Union[int, tuple], shot_strength: int, shot_item: str = None):
         """
         综合模拟发射炮弹操作
         :param shot_angle: 发射的角度，若传递一个元组则执行变角操作
@@ -407,15 +436,16 @@ class Status:
         :param shot_item: 使用的道具按键，多个道具之间用','分隔
         :return: 无返回值
         """
-        self.press(shot_item)
+        if shot_item:
+            self.press(shot_item)
         if type(shot_angle) == int:
             self.change_angle(self.ocr('angle'), shot_angle)
             self.press_shot(shot_strength)
-        elif type(shot_angle) == type:
+        elif type(shot_angle) == tuple:
             self.change_angle(self.ocr('angle'), shot_angle[0])
             self.press_shot(shot_strength)
             for i in range(1, len(shot_angle)):
-                self.sleep(500)
+                self.sleep(800)
                 self.change_angle(self.ocr('angle'), shot_angle[i])
 
     def move(self, move_face: str, move_period: int, reverse_face: bool = False):
